@@ -32,14 +32,11 @@ typedef __int64 int64;
 #include <cinttypes>
 
 
-#ifdef M_PI
-#undef M_PI
-#endif
 typedef int64_t int64;
 
 namespace geos {
 
-constexpr double M_PI = 3.14159265358979323846;
+constexpr double MATH_PI = 3.14159265358979323846;
 
 
 
